package com.ynxbd.push.controller;


import com.ynxbd.push.config.IniConfig;
import com.ynxbd.push.entity.tencent.SendMessageTemplate;
import com.ynxbd.push.helper.DesEncryptHelper;
import com.ynxbd.push.helper.MessageApiHelper;
import com.ynxbd.push.quartz.pushJob.TodayReg.TodayReg;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.util.UriUtils;
import weixin.popular.bean.message.MessageSendResult;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.util.Base64;


/**
 * @author 李进才
 * @ClassName RegisteredController
 * @Description 微信挂号相关提醒
 * @date 2021/12/6 4:07 下午
 */
@Slf4j
@Controller
public class RegisteredController {

    /**
     * 预约挂号成功提醒 对应我代码规定的第12个模版 code 12
     *
     * @param openId
     * @param deptName
     * @param patientName
     * @param sex
     * @param seq
     * @return
     */
    @GetMapping(value = "AppointmentSuccess")
    @ResponseBody
    public MessageSendResult AppointmentSuccess(String openId, String doctor, String deptName, String patientName, String sex, String seq) throws IOException {
        String templateId = IniConfig.getInstance("templateId12");
        String hospital = IniConfig.getInstance("name");
        openId = DesEncryptHelper.deCode(openId);

        log.info("openid={}, patientName={}, deptName={}, seq={}", openId, patientName, deptName, seq);

        String patientId =patientName.split("ID：")[1];

        String content =new StringBuilder()
                .append(patientName.split("ID：")[0])
                .append(";")
                .append(doctor)
                .append(";")
                .append(deptName)
                .append(";")
                .append(sex)
                .toString();

        SendMessageTemplate sendMessageTemplate = SendMessageTemplate.builder()
                .template_id(templateId)
                .code("12")
                .doctor(doctor)
                .openId(openId)
                .department(deptName)
                .patientName(patientName)
                .hospitalName(hospital)
                .first("预约挂号成功")
                .url(IniConfig.DOMAIN+"wx/"+IniConfig.WECHAT_UI_PATH+"reg-record.html#/reserve")
                .seq(seq)
                .patientSex(sex)
                .remarkColor("#fa4028")
                .remark(IniConfig.getInstance("remark12"))
                .build();

        return MessageApiHelper.templateMessageSend(sendMessageTemplate);
    }

    /**
     * 取消预约挂号 对应我代码规定的第9个模版 code 9
     *
     * @param deptName
     * @param doctor
     * @param treatTime
     * @param openId
     * @param patientName
     * @param seq
     * @return
     * @throws IOException
     */
    @GetMapping(value = "AppointmentCancel")
    @ResponseBody
    public MessageSendResult AppointmentCancel(String deptName, String doctor, String treatTime, String openId, String patientName, String seq) throws IOException {
        String templateId = IniConfig.getInstance("templateId9");
        String hospital = IniConfig.getInstance("name");
        openId = DesEncryptHelper.deCode(openId);
        SendMessageTemplate sendMessageTemplate = SendMessageTemplate.builder()
                .template_id(templateId)
                .openId(openId)
                .keyword1(hospital)
                .keyword2(deptName)
                .keyword3(doctor)
                .keyword4(treatTime)
                .remarkColor("#fa4028")
                .remark(new StringBuilder().append("取消预约,").append("患者姓名：").append(patientName).append(",").append("流水号：").append(seq).toString())
                .build();
        return MessageApiHelper.templateMessageSend(sendMessageTemplate);
    }

    /**
     * 缴费成功提醒 对应我代码规定的第4个模版 code 4
     *
     * @param openId
     * @param patientName
     * @param deptName
     * @param doctor
     * @param allMoney
     * @param payTime
     * @return
     * @throws IOException
     */
    @GetMapping(value = "PaymentSuccess")
    @ResponseBody
    public MessageSendResult PaymentSuccess(String openId, String patientName, String deptName, String doctor, String allMoney, String payTime) throws IOException {
        openId = DesEncryptHelper.deCode(openId);
        String templateId = IniConfig.getInstance("templateId4");
        SendMessageTemplate sendMessageTemplate = SendMessageTemplate.builder()
                .keyword1(patientName)
                .keyword2(deptName)
                .keyword3(doctor)
                .keyword4(allMoney)
                .keyword5(payTime)
                .template_id(templateId)
                .openId(openId)
                .build();
        return MessageApiHelper.templateMessageSend(sendMessageTemplate);
    }

    @GetMapping(value = "todayReg")
    @ResponseBody
    public MessageSendResult todayReg() {
        TodayReg.runJon();
        return new MessageSendResult();
    }

}
