package com.ynxbd.push.controller;


import com.ynxbd.push.entity.*;
import com.ynxbd.push.entity.response.ResponseResult;
import com.ynxbd.push.entity.tencent.*;
import com.ynxbd.push.helper.DesEncryptHelper;
import com.ynxbd.push.httpRequest.tencent.WeChatDataRequest;
import com.ynxbd.push.helper.MessageApiHelper;
import com.ynxbd.push.httpRequest.xbd.wx.WxCacheRequest;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import weixin.popular.bean.message.MessageSendResult;

import java.io.IOException;

/**
 * @author 李进才
 */
@Slf4j
@Controller
public class SendMessageController {


    /**
     * 发送微信客服消息接口
     *
     * @param openId  客户openid,指示哪个用户
     * @param content 内容
     * @return 是否发送成功
     */

    @GetMapping(value = "SendMessage")
    @ResponseBody
    public Boolean sendMessage(String openId, String content) {
        openId = DesEncryptHelper.deCode(openId);
        String messageSendResult = MessageApiHelper.sendTextForOpenId(openId, content).getErrcode();
        return "0".equals(messageSendResult);
    }

    /**
     * 发送微信客服带图片链接消息接口
     *
     * @param openId      客户id，指示哪个用户
     * @param title       标题
     * @param description 描述
     * @param url         跳转链接
     * @param thumbUrl    图片链接
     * @return 是否发送成功
     */

    @PostMapping(value = "SendLinkMessage")
    @ResponseBody
    public Boolean sendLinkMessage(String openId, String title, String description, String url, String thumbUrl) {
        openId = DesEncryptHelper.deCode(openId);
        String messageSendResult = MessageApiHelper.sendLinkForOpenId(openId, title, description, url, thumbUrl).getErrcode();
        return "0".equals(messageSendResult);
    }

    /**
     * 群发消息接口
     *
     * @param content 内容
     * @return 是否发送成功
     */
    @GetMapping(value = "GroupMessage")
    @ResponseBody
    public Boolean groupMessage(String content) {
        if (content == null) {
            return false;
        }
        String messageSendResult = MessageApiHelper.group(content).getErrcode();
        return "0".equals(messageSendResult);
    }

    /**
     * 发送模板信息接口
     *
     * @param sendMessageTemplate 不同模板的对应参数
     * @return 是否发送成功
     */
    @PostMapping(value = "TemplateMessageSend")
    @ResponseBody
    public MessageSendResult templateMessageSend(SendMessageTemplate sendMessageTemplate) {
        if (StringUtils.isNotBlank(sendMessageTemplate.getDoctorCode())&& !StringUtils.isNotBlank(sendMessageTemplate.getOpenId())) {
            if(WeChatDataRequest.getOpenIdForDoctorCode(sendMessageTemplate.getDoctorCode())==null){
                return ResponseResult.DOCTOR_NOT_BIND.toMessResult();
            }
            sendMessageTemplate.setOpenId(WeChatDataRequest.getOpenIdForDoctorCode(sendMessageTemplate.getDoctorCode()).get(0));
        }
        if (StringUtils.isNotBlank(sendMessageTemplate.getTemplate_name()) && !StringUtils.isNotBlank(sendMessageTemplate.getTemplate_id())) {
            sendMessageTemplate.setTemplate_id(WeChatDataRequest.getTemplateId(sendMessageTemplate.getTemplate_name()));
        }
        log.info("template_id:" + sendMessageTemplate.getTemplate_id());
        log.info("code:" + sendMessageTemplate.getCode());
        log.info("open_id:" + sendMessageTemplate.getOpenId());

        sendMessageTemplate.setOpenId(DesEncryptHelper.deCode(sendMessageTemplate.getOpenId()));
        return MessageApiHelper.templateMessageSend(sendMessageTemplate);
    }

    /**
     * 请求access_token
     *
     * @return access_token值
     */
    @PostMapping(value = "AccessToken")
    @ResponseBody
    public String accessToken() {
        return WxCacheRequest.getAccessToken();
    }


    /**
     * 获取微信用户详细信息
     *
     * @param openId
     * @return
     * @throws Exception
     */
    @PostMapping(value = "UserInfo")
    @ResponseBody
    public WeChatUserInfo userInfo(String openId) throws Exception {
        log.info("UserInfo:OpenId=" + DesEncryptHelper.deCode(openId));
        return WeChatDataRequest.userInfo(DesEncryptHelper.deCode(openId));
    }

    /**
     * 解密
     *
     * @param openId
     * @return
     */
    @GetMapping(value = "Encode")
    @ResponseBody
    public String encode(String openId) {
        return DesEncryptHelper.enCode(openId);
    }

    /**
     * 获取所有用户openid
     *
     * @param nextOpenid
     * @return
     * @throws Exception
     */
    @PostMapping(value = "GetAllUser")
    @ResponseBody
    public AllUser getAllUser(String nextOpenid) {
        return MessageApiHelper.getAllUser(nextOpenid);
    }

    /**
     * 群发模版消息
     *
     * @param sendMessageTemplate
     * @return
     * @throws Exception
     */
    @PostMapping(value = "GroupTemplateMessage")
    @ResponseBody
    public CompleteThreadCount groupTemplateMessage(SendMessageTemplate sendMessageTemplate) throws IOException, InterruptedException {
        return MessageApiHelper.groupTemplateSend(sendMessageTemplate);
    }


    @PostMapping(value = "SubscribeMessage")
    @ResponseBody
    public MessageSendResult subscribeMessage(Subscribe subscribe) throws Exception {
        return MessageApiHelper.subscribeMessage(subscribe);
    }
}
