package com.ynxbd.push.helper;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.ynxbd.push.entity.tencent.TemplateJson;
import com.ynxbd.push.entity.tencent.TemplateJsonValue;
import com.ynxbd.push.entity.tencent.TemplateRemark;
import org.apache.commons.lang3.StringUtils;

import java.util.HashMap;
import java.util.Map;

/**
 * 组装请求的json内容
 * @author 李进才
 */
public class TemplateAllKeyWordJson {

    /**
     * 模板请求 拼接data 没有小程序跳转
     *
     * @param templateId 模板id
     * @param openId     openid
     * @param url        跳转链接
     * @param first      first
     * @param remark     备注
     * @param keywords   按关键字填写
     */
    public static String getTemplateJsonData(String templateId, String openId, String url, TemplateRemark first, TemplateRemark remark,
                                         TemplateJsonValue... keywords) throws JsonProcessingException {
        Map<String, Object> data = new HashMap<>();
        data.put("first", first);
        data.put("remark", remark);

        if (keywords != null && keywords.length > 0) {
            Map<String, Object> itemMap;
            TemplateJsonValue item;
            for (int i = 0; i < keywords.length; i++) {
                itemMap = new HashMap<>();
                item = keywords[i];
                if (item == null) {
                    data.put(("keyword" + (i + 1)), null);
                    continue;
                }
                String color = item.getColor();
                if (color != null) {
                    itemMap.put("color", color);
                }
                itemMap.put("value", item.getValue());
                data.put(("keyword" + (i + 1)), itemMap);
            }
        }

        return getTemplateJson(templateId, openId, url, data);
    }



    /**
     * 模板请求 拼接data 有小程序跳转
     *
     * @param templateId 模板id
     * @param openId     openid
     * @param url        跳转链接
     * @param first      first
     * @param remark     备注
     * @param keywords   按关键字填写
     */
    public static String getTemplateJsonData(String templateId, String openId, String url, String appId, String pagePath, TemplateRemark first, TemplateRemark remark,
                                         TemplateJsonValue... keywords) throws JsonProcessingException {
        Map<String, Object> data = new HashMap<>();
        data.put("first", first);
        data.put("remark", remark);

        if (keywords != null && keywords.length > 0) {
            Map<String, Object> itemMap;
            TemplateJsonValue item;
            for (int i = 0; i < keywords.length; i++) {
                itemMap = new HashMap<>();
                item = keywords[i];
                if (item == null) {
                    data.put(("keyword" + (i + 1)), null);
                    continue;
                }
                String color = item.getColor();
                if (color != null) {
                    itemMap.put("color", color);
                }

                itemMap.put("value", item.getValue());
                data.put(("keyword" + (i + 1)), itemMap);
            }
        }

        if(StringUtils.isNotBlank(appId)&&StringUtils.isNotBlank(pagePath)){
            return getTemplateJson(templateId, openId, url, data, appId, pagePath);
        }
        return getTemplateJson(templateId, openId, url, data);
    }

    /**
     * 最终json组合，上面的内容是组装date，有小程序内容跳转
     *
     * @param templateId
     * @param openId
     * @param url
     * @param data
     * @param appId
     * @param pagePath
     * @return
     * @throws JsonProcessingException
     */
    private static String getTemplateJson(String templateId, String openId, String url, Map<String, Object> data, String appId, String pagePath) throws JsonProcessingException {
        Map<String, Object> miniProgram = new HashMap<>();
        miniProgram.put("appid", appId);
        miniProgram.put("pagepath", pagePath);
        TemplateJson templateJson = TemplateJson.builder()
                .template_id(templateId)
                .miniprogram(miniProgram)
                .touser(openId)
                .url(url)
                .data(data)
                .build();

        return new ObjectMapper().writeValueAsString(templateJson);
    }

    /**
     * 最终组合，上面的是组装date，没有小程序跳转
     *
     * @param templateId
     * @param openId
     * @param url
     * @param data
     * @return
     * @throws JsonProcessingException
     */
    private static String getTemplateJson(String templateId, String openId, String url, Map<String, Object> data) throws JsonProcessingException {
        TemplateJson templateJson = TemplateJson.builder()
                .template_id(templateId)
                .touser(openId)
                .url(url)
                .data(data)
                .build();

        return new ObjectMapper().writeValueAsString(templateJson);
    }
}
