package com.ynxbd.push.httpRequest.tencent;


import com.alibaba.fastjson.JSONObject;
import com.ynxbd.push.config.IniConfig;
import com.ynxbd.push.entity.tencent.*;
import com.ynxbd.push.entity.xbd.wx.Register;
import com.ynxbd.push.entity.xbd.wx.WorkLoadResponse;
import com.ynxbd.push.helper.DesEncryptHelper;
import com.ynxbd.push.helper.RedisHelper;
import com.ynxbd.push.helper.RequestHelper;
import com.ynxbd.push.httpRequest.xbd.wx.WxCacheRequest;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.Header;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.client.methods.RequestBuilder;
import weixin.popular.api.API;
import weixin.popular.client.LocalHttpClient;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;


/**
 * 获取微信用户信息接口
 *
 * @author 李进才
 */
@Slf4j
public class WeChatDataRequest {
    private WeChatDataRequest() {
    }

    protected static Header jsonHeader;

    public static WeChatUserInfo userInfo(String openId) {
        HttpUriRequest httpUriRequest = RequestBuilder.get().setHeader(jsonHeader).setUri("https://api.weixin.qq.com/cgi-bin/user/info").addParameter("access_token", API.accessToken(WxCacheRequest.getAccessToken())).addParameter("openid", openId).addParameter("lang", "zh_CN").build();
        return LocalHttpClient.executeJsonResult(httpUriRequest, WeChatUserInfo.class);
    }

    public static List<String> getOpenIdForDoctorCode(String doctorCode) {
        return RequestHelper.get("http://127.0.0.1:9090/micro/msg_push/doctor?doctCode="+doctorCode, null, WeChatResponse.class).getData();
    }

    public static List<String> getAllOpenIdForDoctorCode(String doctorCode) {
        return RequestHelper.get("http://127.0.0.1:9090/micro/msg_push/doctorOpenIds?doctCode="+doctorCode, null, WeChatResponse.class).getData();
    }

    public static List<String> getAllOpenIdForDeptCode(String deptCode){
        return RequestHelper.get("http://127.0.0.1:9090/micro/msg_push/deptOpenIds?deptCode="+deptCode, null, WeChatResponse.class).getData();
    }

    public static WeChatAllDoctorResponse getAllOpenIdForDoctorCode() {
        return RequestHelper.get("http://127.0.0.1:9090/micro/msg_push/doctorOpenIdTree", null, WeChatAllDoctorResponse.class);
    }

    public static WorkLoadResponse getOpenIdAndTokenToBi() {
        return RequestHelper.get("http://127.0.0.1:9090/micro/doctor/getDocModuleLink?code=xsjc", null, WorkLoadResponse.class);
    }

    public static List<Register> getTodayRegOpenId(){
        return JSONObject.parseArray(RequestHelper.getJsonObj(IniConfig.getInstance("today_reg_url")==null?"http://127.0.0.1/wx/register/getTodayRegOpenId":IniConfig.getInstance("today_reg_url"),null).get("data").toString(),Register.class);
    }

    public static List<Register> getTodayRegRecord(String startTime, String endTime){
        return JSONObject.parseArray(RequestHelper.getJsonObj("http://127.0.0.1/wx/register/getTodayRegRecord?startTime="+startTime+"&endTime="+endTime,null).get("data").toString(),Register.class);
    }

    public static String todayRegSmS(String startTime, String endTime){
        return RequestHelper.getJsonObj("http://127.0.0.1/wx/api/sms/todayRegSmS?startTime="+startTime+"&endTime="+endTime,null).toString();
    }

    public static String GetOpenIdForPatientId(String patientId){
        String wx_openId_url = "http://wx.mzsrmyy.net/wx/patient/getOpenIdsByPatientId.do";
        Map<String, String> params = new HashMap<>();
        params.put("patientId",patientId);
        params.put("algorithm","des");
        params.put("isEncryptComma","false");
        return DesEncryptHelper.deCode(RequestHelper.get(wx_openId_url,params,WeChatResponse.class).getData().get(0));
    }

    private static TemplateList getTemplateList() {
        if(RedisHelper.getRedis().get("Template")!=null){
            return JSONObject.parseObject(RedisHelper.getRedis().get("Template"), TemplateList.class);
        }
        String tenCentTemplateListUrl = "https://api.weixin.qq.com/cgi-bin/template/get_all_private_template?access_token="+API.accessToken(WxCacheRequest.getAccessToken());
        Map<String,String> params = new HashMap<>();
        params.put("lang","zh_CN");
        TemplateList templateList = RequestHelper.get(tenCentTemplateListUrl,params,TemplateList.class);
        RedisHelper.getRedis().set("Template", JSONObject.toJSONString(templateList),86400);
        return templateList;
    }

    public static String getTemplateId(String title) {
        List<Template>  templateList= getTemplateList().getTemplate_list().stream().filter(p -> p.getTitle().equals(title)).collect(Collectors.toList());
        if(templateList.isEmpty()){
            log.error("获取模版列表失败，模版名称-{}",title);
            return null;
        }
        if(templateList.size()>1){
            if(templateList.stream().anyMatch(p->p.getDeputy_industry()==null)){
                return templateList.stream().filter(p->p.getDeputy_industry()==null).findFirst().get().getTemplate_id();
            }
        }
        return templateList.get(0).getTemplate_id();
    }
}
