package com.ynxbd.push.quartz.job;


import com.ynxbd.push.config.IniConfig;
import com.ynxbd.push.entity.tencent.SendMessageTemplate;
import com.ynxbd.push.helper.MessageApiHelper;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.quartz.Job;
import org.quartz.JobExecutionContext;

import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * 任务调度-定时推送每日工作量表
 * @author 李进才
 */
@Slf4j
public class TimePushJob implements Job {


    @SneakyThrows
    @Override
    public void execute(JobExecutionContext jobExecutionContext) {

        if(IniConfig.getInstance("lisTemplateId")==null){
            return;
        }
        SimpleDateFormat sdf = new SimpleDateFormat();
        sdf.applyPattern("yyyy-MM-dd HH:mm:ss a");
        Date date = new Date();
        SendMessageTemplate sendMessageTemplate = SendMessageTemplate.builder()
                .template_id(IniConfig.getInstance("lisTemplateId"))
                .keyword1("医学检验科")
                .keyword2("检验日报")
                .keyword3(sdf.format(date))
                .keyword4("点击查看详情")
                .remark(new StringBuilder().append(sdf.format(date)).append("工作日报").toString())
                .url(IniConfig.getInstance("lisUrl"))
                .build();

        String lisPeoples = IniConfig.getInstance("lisPeople");
        for (String lisPeople: lisPeoples.split(";")) {
            sendMessageTemplate.setOpenId(lisPeople);
            log.info("定时任务推送每日工作量表：openId={}, ErrCode={}, ",
                    sendMessageTemplate.getOpenId(),
                    MessageApiHelper.templateMessageSend(sendMessageTemplate).getMsg_status()); // 推送
        }
    }
}
