package com.ynxbd.push.service;


import com.alibaba.fastjson.JSONObject;
import com.ynxbd.push.config.IniConfig;
import com.ynxbd.push.entity.enums.HisApiEnum;
import com.ynxbd.push.entity.enums.MsgParamEnum;
import com.ynxbd.push.entity.response.ResponseResult;
import com.ynxbd.push.entity.type.MessageTypeEnum;
import com.ynxbd.push.helper.DesEncryptHelper;
import com.ynxbd.push.httpRequest.tencent.WeChatDataRequest;
import com.ynxbd.push.rabbit.send.RabbitSender;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;
import weixin.popular.bean.message.MessageSendResult;

import java.util.HashMap;
import java.util.Map;

@Slf4j
@Service
public class HisUniversalService {
    @Autowired
    private RabbitSender rabbitSender;


    public MessageSendResult hisUniversal(Map<String, String> paramsMap) {
        String callNo = paramsMap.get("callNo");
        HisApiEnum hisApiEnum = HisApiEnum.toEnum(callNo);
        if (hisApiEnum == null) {
            return ResponseResult.CALL_NO_IS_NOT_FIND.toMessResult();
        }

        log.info("[{}]推送开始...", hisApiEnum.TITLE);
        String templateId = WeChatDataRequest.getTemplateId(hisApiEnum.TITLE);
        if (ObjectUtils.isEmpty(templateId)) {
            return ResponseResult.TEMPLATE_ID_IS_NOT_FIND.toMessResult();
        }

        switch (hisApiEnum) {
            case payment_end_04__001:
                return payment_end_04__001(paramsMap, templateId, hisApiEnum.TITLE);

            case payment_remind_04__001:
                return payment_remind_04__001(paramsMap, templateId, hisApiEnum.TITLE);

            case reg_success_04__001:
                return reg_success_04__001(paramsMap, templateId, hisApiEnum.TITLE);

            case report_notice_05__001:
                return report_notice_05__001(paramsMap, templateId, hisApiEnum.TITLE);

            case work_order_remind_02__001:
                return work_order_remind_02__001(paramsMap, templateId, hisApiEnum.TITLE);

            case doctor_admissions_05_001:
                return doctor_admissions_05_001(paramsMap, templateId, hisApiEnum.TITLE);

        }
        return ResponseResult.CALL_NO_IS_NOT_FIND.toMessResult();
    }


    /**
     * 创建一个data模板
     *
     * @param paramsMap  入参map
     * @param templateId 模板ID
     * @param url        [传递null时，从请求中取值；传递空字符串""时，表示没有链接]
     */
    public Map<String, Object> createTemplate(Map<String, String> paramsMap, String templateId, String title, String url) throws Exception {
        String organizeName = paramsMap.get("organizeName");
        if (ObjectUtils.isEmpty(organizeName)) {
            throw new Exception("组织机构代码为空");
        }
        organizeName = DesEncryptHelper.deCode(organizeName);
        if (organizeName.equals("error:null")) {
            throw new Exception("组织机构代码为空 organizeName=" + organizeName);
        }

        Map<String, Object> tempData = new HashMap<>();
        if (url == null) { // 传递值为空，取请求中的url链接
            url = paramsMap.get("url");
        }
        // 页面路径[入参url]
        tempData.put(MsgParamEnum.URL.CODE, ObjectUtils.isEmpty(url) ? "" : url);
        // tip
        tempData.put(MsgParamEnum.TIP.CODE, MessageTypeEnum.COMMON.CODE);
        // 模板ID
        tempData.put(MsgParamEnum.TEMPLATE_ID.CODE, templateId);
        tempData.put(MsgParamEnum.TITLE.CODE, title);

        String patientId = paramsMap.get("patientId");
        String doctorCode = paramsMap.get("doctorCode");
        String cardNo = paramsMap.get("cardNo");
        String openId = paramsMap.get("openId");
        if (ObjectUtils.isEmpty(patientId) && ObjectUtils.isEmpty(doctorCode) && ObjectUtils.isEmpty(cardNo)&&ObjectUtils.isEmpty(openId)) {
            throw new Exception("查询信息的参数缺失");
        }

        if (!ObjectUtils.isEmpty(patientId)) {
            tempData.put("patientId", patientId);
        }
        if (!ObjectUtils.isEmpty(doctorCode)) {
            tempData.put("doctorCode", doctorCode);
        }
        if(!ObjectUtils.isEmpty(openId)) {
            tempData.put("openId", openId);
        }
        if (!ObjectUtils.isEmpty(cardNo)) {
            tempData.put("cardNo", cardNo);
        }
        return tempData;
    }


    /**
     * 缴费完成通知（就诊人、缴费时间、缴费金额、治疗地点）
     *
     * @param paramsMap 参数集
     * @return MessageSendResult
     */
    public MessageSendResult payment_end_04__001(Map<String, String> paramsMap, String templateId, String title) {
        try {
            String url = IniConfig.getWxWebPath(true) + "pay-info.html#/recipe-payed";
            Map<String, Object> tempData = createTemplate(paramsMap, templateId, title, url);
            // 就诊人
            String patientName = MsgParamEnum.THING.put(paramsMap, tempData, "patientName", 1);
            // 缴费时间
            String time = MsgParamEnum.TIME.put(paramsMap, tempData, "time", 4);
            // 缴费金额
            String money = MsgParamEnum.AMOUNT.put(paramsMap, tempData, "money", 3);
            // 治疗地点
            String address = MsgParamEnum.THING.put(paramsMap, tempData, "address", 17);

            rabbitSender.sendByTip(tempData);
            return ResponseResult.JOIN_QUEUE.toMessResult();
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseResult.PARAMETER_IS_NULL.toMessResult();
        }
    }


    public MessageSendResult reg_today_tip_05_001(Map<String, String> paramsMap, String templateId, String title){
        try {
            Map<String, Object> tempData = createTemplate(paramsMap, templateId, title, "");

            // 就诊人
            String patientName = MsgParamEnum.THING.put(paramsMap, tempData, "patientName", 1);
            // 就诊科室
            String deptName = MsgParamEnum.THING.put(paramsMap, tempData, "deptName", 2);
            // 就诊时间
            String time = MsgParamEnum.TIME.put(paramsMap, tempData, "time", 6);
            // 候诊地点
            String address = MsgParamEnum.THING.put(paramsMap, tempData, "address", 7);
            String doctorName = MsgParamEnum.THING.put(paramsMap, tempData, "doctorName", 12);

            rabbitSender.sendByTip(tempData);
            return ResponseResult.JOIN_QUEUE.toMessResult();
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseResult.PARAMETER_IS_NULL.toMessResult();
        }
    }

    /**
     * 缴费提醒（患者姓名、开单时间、缴费项目、金额）
     *
     * @param paramsMap
     * @param templateId
     * @return
     */
    private MessageSendResult payment_remind_04__001(Map<String, String> paramsMap, String templateId, String title) {
        try {
            String url = IniConfig.getWxWebPath(true) + "pay-info.html#/recipe-unpay";
            Map<String, Object> tempData = createTemplate(paramsMap, templateId, title, url);

            // 患者姓名
            String patientName = MsgParamEnum.THING.put(paramsMap, tempData, "patientName", 14);
            // 开单时间
            String time = MsgParamEnum.TIME.put(paramsMap, tempData, "time", 17);
            // 缴费项目
            String projectName = MsgParamEnum.THING.put(paramsMap, tempData, "projectName", 10);
            // 金额
            String money = MsgParamEnum.AMOUNT.put(paramsMap, tempData, "money", 3);

            rabbitSender.sendByTip(tempData);
            return ResponseResult.JOIN_QUEUE.toMessResult();
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseResult.PARAMETER_IS_NULL.toMessResult();
        }
    }


    /**
     * 预约挂号成功通知（就诊人、就诊科室、预约时间、就诊地点）
     *
     * @param paramsMap
     * @param templateId
     * @return
     */
    private MessageSendResult reg_success_04__001(Map<String, String> paramsMap, String templateId, String title) {
        try {
            Map<String, Object> tempData = createTemplate(paramsMap, templateId, title, "");

            // 就诊人
            String patientName = MsgParamEnum.THING.put(paramsMap, tempData, "patientName", 28);
            // 就诊科室
            String deptName = MsgParamEnum.THING.put(paramsMap, tempData, "deptName", 22);
            // 预约时间
            String time = MsgParamEnum.TIME.put(paramsMap, tempData, "time", 21);
            // 就诊地点
            String address = MsgParamEnum.THING.put(paramsMap, tempData, "address", 6);

            rabbitSender.sendByTip(tempData);
            return ResponseResult.JOIN_QUEUE.toMessResult();
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseResult.PARAMETER_IS_NULL.toMessResult();
        }
    }

    /**
     * 检验检查报告通知（就诊卡号、就诊人、单号、检查时间、项目）
     *
     * @param paramsMap
     * @param templateId
     * @return
     */
    private MessageSendResult report_notice_05__001(Map<String, String> paramsMap, String templateId, String title) {
        try {
            Map<String, Object> tempData = createTemplate(paramsMap, templateId, title, null);
            // 就诊卡号
            MsgParamEnum.CHARACTER_STRING.put(paramsMap, tempData, "cardNo", 12);
            // 就诊人
            MsgParamEnum.THING.put(paramsMap, tempData, "patientName", 3);
            // 单号
            MsgParamEnum.CHARACTER_STRING.put(paramsMap, tempData, "orderNo", 9);
            // 检查时间
            MsgParamEnum.TIME.put(paramsMap, tempData, "time", 14);
            // 项目名称
            MsgParamEnum.THING.put(paramsMap, tempData, "projectName", 5);

            rabbitSender.sendByTip(tempData);
            return ResponseResult.JOIN_QUEUE.toMessResult();
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseResult.PARAMETER_IS_NULL.toMessResult();
        }
    }

    /**
     * 工单处理提醒（就诊卡号、就诊人、单号、检查时间、项目名称）
     *
     * @param paramsMap
     * @param templateId
     * @return
     */
    private MessageSendResult work_order_remind_02__001(Map<String, String> paramsMap, String templateId, String title) {
        try {
            Map<String, Object> tempData = createTemplate(paramsMap, templateId, title, "");
            // 提交时间
            MsgParamEnum.TIME.put(paramsMap, tempData, "time", 13);
            // 工单名称
            MsgParamEnum.THING.put(paramsMap, tempData, "projectName", 16);

            rabbitSender.sendByTip(tempData);
            return ResponseResult.JOIN_QUEUE.toMessResult();
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseResult.PARAMETER_IS_NULL.toMessResult();
        }
    }

    private MessageSendResult doctor_admissions_05_001(Map<String, String> paramsMap, String templateId, String title) {
        try {
            Map<String, Object> tempData = createTemplate(paramsMap, templateId, title, null);
            // 医生
            MsgParamEnum.THING.put(paramsMap, tempData, "doctorName", 4);
            // 就诊人
            MsgParamEnum.THING.put(paramsMap, tempData, "patientName", 1);
            //医疗项目
            MsgParamEnum.THING.put(paramsMap, tempData, "item", 5);
            //就诊时间
            MsgParamEnum.TIME.put(paramsMap, tempData, "time", 7);
            //科室
            MsgParamEnum.THING.put(paramsMap, tempData, "deptName", 3);


            rabbitSender.sendByTip(tempData);
            return ResponseResult.JOIN_QUEUE.toMessResult();
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseResult.PARAMETER_IS_NULL.toMessResult();
        }
    }


    public static void main(String[] args) {
        Map<String, Object> map = new HashMap<>();
        map.put("a", 1);
        map.put("b", "2");
        map.put("c", new HashMap<String, String>() {{
            put("d", "1");
        }});

        log.info(JSONObject.toJSONString(map));
        Map<String, String> map2 = new HashMap<>();
        for (Map.Entry<String, Object> item : map.entrySet()) {
            String key = item.getKey();
            Object value = item.getValue();
            if (value == null) {
                map2.put(item.getKey(), null);
                break;
            }
            if (value instanceof Map) {
                map2.put(key, JSONObject.toJSONString(value));
            } else {
                map2.put(key, String.valueOf(value));
            }
        }
        log.info(JSONObject.toJSONString(map2));

        map = new HashMap<>();
        for (Map.Entry<String, String> item : map2.entrySet()) {
            String key = item.getKey();
            String value = item.getValue();
            if (value == null) {
                map.put(item.getKey(), null);
                break;
            }
            map.put(key, JSONObject.parse(value));
        }
        log.info(JSONObject.toJSONString(map));
    }
}
